@@ -4,13 +4,13 @@ import textwrap
 from shutil import get_terminal_size
 from typing import Optional
 
-from pip._vendor.pkg_resources import safe_name
-
 from pdm import termui
 from pdm._types import SearchResult
 from pdm.cli.commands.base import BaseCommand
+from pdm.cli.options import verbose_option
 from pdm.models.environment import WorkingSet
 from pdm.project import Project
+from pdm.utils import normalize_name
 
 
 def print_results(
@@ -18,12 +18,10 @@ def print_results(
     hits: SearchResult,
     working_set: WorkingSet,
     terminal_width: Optional[int] = None,
-):
+) -> None:
     if not hits:
         return
-    name_column_width = (
-        max([len(hit.name) + len(hit.version or "") for hit in hits]) + 4
-    )
+    name_column_width = max(len(hit.name) + len(hit.version or "") for hit in hits) + 4
 
     for hit in hits:
         name = hit.name
@@ -33,8 +31,9 @@ def print_results(
             target_width = terminal_width - name_column_width - 5
             if target_width > 10:
                 # wrap and indent summary to fit terminal
-                summary = textwrap.wrap(summary, target_width)
-                summary = ("\n" + " " * (name_column_width + 2)).join(summary)
+                summary = ("\n" + " " * (name_column_width + 2)).join(
+                    textwrap.wrap(summary, target_width)
+                )
         current_width = len(name) + len(latest) + 4
         spaces = " " * (name_column_width - current_width)
         line = "{name} ({latest}){spaces} - {summary}".format(
@@ -45,8 +44,8 @@ def print_results(
         )
         try:
             ui.echo(line)
-            if safe_name(name).lower() in working_set:
-                dist = working_set[safe_name(name).lower()]
+            if normalize_name(name) in working_set:
+                dist = working_set[normalize_name(name)]
                 if dist.version == latest:
                     ui.echo("  INSTALLED: %s (latest)" % dist.version)
                 else:
@@ -59,6 +58,8 @@ def print_results(
 class Command(BaseCommand):
     """Search for PyPI packages"""
 
+    arguments = [verbose_option]
+
     def add_arguments(self, parser: argparse.ArgumentParser) -> None:
         parser.add_argument("query", help="Query string to search")
 
