@@ -4,8 +4,9 @@ import io
 import json
 import os
 import stat
+from functools import lru_cache
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, cast
+from typing import TYPE_CHECKING, cast
 
 from installer import __version__
 from installer._core import _determine_scheme, _process_WHEEL_file
@@ -16,15 +17,94 @@ from installer.sources import WheelFile as _WheelFile
 from installer.utils import parse_entrypoints
 
 from pdm.installers.packages import CachedPackage
-from pdm.models.environment import Environment
 from pdm.termui import logger
-from pdm.utils import cached_property
+from pdm.utils import cached_property, fs_supports_symlink
 
 if TYPE_CHECKING:
-    from typing import BinaryIO
+    from typing import Any, BinaryIO, Callable, Iterable
 
     from installer.destinations import Scheme
 
+    from pdm.models.environment import Environment
+
+
+@lru_cache()
+def _is_python_package(root: str | Path) -> bool:
+    for child in Path(root).iterdir():
+        if (
+            child.is_file()
+            and child.suffix in (".py", ".pyc", ".pyo", ".pyd")
+            or child.is_dir()
+            and _is_python_package(child)
+        ):
+            return True
+    return False
+
+
+@lru_cache()
+def _is_namespace_package(root: str) -> bool:
+    if not _is_python_package(root):
+        return False
+    if not os.path.exists(os.path.join(root, "__init__.py")):  # PEP 420 style
+        return True
+    int_py_lines = [
+        line.strip()
+        for line in Path(root, "__init__.py").open(encoding="utf-8")
+        if line.strip() and not line.strip().startswith("#")
+    ]
+    namespace_identifiers = [
+        # pkg_resources style
+        "__import__('pkg_resources').declare_namespace(__name__)",
+        # pkgutil style
+        "__path__ = __import__('pkgutil').extend_path(__path__, __name__)",
+    ]
+    checker = namespace_identifiers[:]
+    checker.extend(item.replace("'", '"') for item in namespace_identifiers)
+    return any(line in checker for line in int_py_lines)
+
+
+def _create_symlinks_recursively(source: str, destination: str) -> Iterable[str]:
+    """Create symlinks recursively from source to destination.
+    Caveats: This don't work for pkgutil or pkg_resources namespace packages.
+    package  <-- link
+        __init__.py
+    namespace_package  <-- mkdir
+        foo.py  <-- link
+        bar.py  <-- link
+    """
+    is_top = True
+    for root, dirs, files in os.walk(source):
+        bn = os.path.basename(root)
+        if bn == "__pycache__" or bn.endswith(".dist-info"):
+            dirs[:] = []
+            continue
+        relpath = os.path.relpath(root, source)
+        destination_root = os.path.join(destination, relpath)
+        if is_top:
+            is_top = False
+        elif not _is_namespace_package(root):
+            # A package, create link for the parent dir and don't proceed
+            # for child directories
+            if os.path.exists(destination_root):
+                os.remove(destination_root)
+            os.symlink(root, destination_root, True)
+            yield relpath
+            dirs[:] = []
+            continue
+        # Otherwise, the directory is likely a namespace package,
+        # mkdir and create links for all files inside.
+        if not os.path.exists(destination_root):
+            os.makedirs(destination_root)
+        for f in files:
+            if f.endswith(".pyc"):
+                continue
+            source_path = os.path.join(root, f)
+            destination_path = os.path.join(destination_root, f)
+            if os.path.exists(destination_path):
+                os.remove(destination_path)
+            os.symlink(source_path, destination_path, False)
+            yield os.path.join(relpath, f)
+
 
 class WheelFile(_WheelFile):
     @cached_property
@@ -44,8 +124,11 @@ class WheelFile(_WheelFile):
 
 
 class InstallDestination(SchemeDictionaryDestination):
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
+    def __init__(
+        self, *args: Any, symlink_to: str | None = None, **kwargs: Any
+    ) -> None:
         super().__init__(*args, **kwargs)
+        self.symlink_to = symlink_to
         self.root_scheme = cast("Scheme", "purelib")
 
     def write_to_fs(
@@ -61,6 +144,20 @@ class InstallDestination(SchemeDictionaryDestination):
         record.path = record_path
         return record
 
+    def finalize_installation(
+        self,
+        scheme: Scheme,
+        record_file_path: str | Path,
+        records: list[RecordEntry],
+    ) -> None:
+        if self.symlink_to:
+            # Create symlinks to the cached location
+            for relpath in _create_symlinks_recursively(
+                self.symlink_to, self.scheme_dict[scheme]
+            ):
+                records.append(RecordEntry(relpath.replace("\\", "/"), None, None))
+        return super().finalize_installation(scheme, record_file_path, records)
+
 
 def install_wheel(
     wheel: str, environment: Environment, direct_url: dict[str, Any] | None = None
@@ -71,12 +168,13 @@ def install_wheel(
         additional_metadata = {
             "direct_url.json": json.dumps(direct_url, indent=2).encode()
         }
-    _install_wheel(
-        wheel=wheel,
+    destination = InstallDestination(
+        scheme_dict=environment.get_paths(),
         interpreter=environment.interpreter.executable,
         script_kind=_get_kind(environment),
-        scheme_dict=environment.get_paths(),
-        additional_metadata=additional_metadata,
+    )
+    _install_wheel(
+        wheel=wheel, destination=destination, additional_metadata=additional_metadata
     )
 
 
@@ -91,15 +189,19 @@ def install_wheel_with_cache(
     package_cache = CachedPackage(cache_path)
     interpreter = environment.interpreter.executable
     script_kind = _get_kind(environment)
+    supports_symlink = (
+        environment.project.config["feature.install_cache_method"] == "symlink"
+        and fs_supports_symlink()
+    )
     if not cache_path.is_dir():
         logger.debug("Installing wheel into cached location %s", cache_path)
         cache_path.mkdir(exist_ok=True)
-        _install_wheel(
-            wheel=wheel,
+        destination = InstallDestination(
+            scheme_dict=package_cache.scheme(),
             interpreter=interpreter,
             script_kind=script_kind,
-            scheme_dict=package_cache.scheme(),
         )
+        _install_wheel(wheel=wheel, destination=destination)
 
     additional_metadata = {"REFER_TO": package_cache.path.as_posix().encode()}
 
@@ -114,20 +216,30 @@ def install_wheel_with_cache(
             or path.split("/")[0].endswith(".dist-info")
             # We need to skip the *-nspkg.pth files generated by setuptools'
             # namespace_packages merchanism. See issue#623 for details
-            or path.endswith(".pth")
+            or not supports_symlink
+            and path.endswith(".pth")
             and not path.endswith("-nspkg.pth")
         )
 
-    filename = wheel_stem.split("-")[0] + ".pth"
+    additional_files: Iterable[tuple[Scheme | None, str, io.BytesIO]] | None = None
     lib_path = package_cache.scheme()["purelib"]
+    if not supports_symlink:
+        # HACK: Prefix with aaa_ to make it processed as early as possible
+        filename = "aaa_" + wheel_stem.split("-")[0] + ".pth"
+        additional_files = [(None, filename, io.BytesIO(f"{lib_path}\n".encode()))]
+
+    destination = InstallDestination(
+        scheme_dict=environment.get_paths(),
+        interpreter=interpreter,
+        script_kind=script_kind,
+        symlink_to=lib_path if supports_symlink else None,
+    )
 
     dist_info_dir = _install_wheel(
         wheel=wheel,
-        interpreter=interpreter,
-        script_kind=script_kind,
-        scheme_dict=environment.get_paths(),
+        destination=destination,
         excludes=skip_files,
-        additional_files=[(None, filename, io.BytesIO(f"{lib_path}\n".encode()))],
+        additional_files=additional_files,
         additional_metadata=additional_metadata,
     )
     package_cache.add_referrer(dist_info_dir)
@@ -135,11 +247,9 @@ def install_wheel_with_cache(
 
 def _install_wheel(
     wheel: str,
-    interpreter: str,
-    script_kind: str,
-    scheme_dict: dict[str, str],
+    destination: InstallDestination,
     excludes: Callable[[Scheme, str], bool] | None = None,
-    additional_files: list[tuple[Scheme | None, str, BinaryIO]] | None = None,
+    additional_files: Iterable[tuple[Scheme | None, str, BinaryIO]] | None = None,
     additional_metadata: dict[str, bytes] | None = None,
 ) -> str:
     """A lower level installation method that is copied from installer
@@ -147,12 +257,6 @@ def _install_wheel(
 
     Return the .dist-info path
     """
-    destination = InstallDestination(
-        scheme_dict,
-        interpreter=interpreter,
-        script_kind=script_kind,
-    )
-
     with WheelFile.open(wheel) as source:
         root_scheme = _process_WHEEL_file(source)
         destination.root_scheme = root_scheme
@@ -192,7 +296,9 @@ def _install_wheel(
                 stream=stream,
             )
             # add executable bit if necessary
-            target_path = os.path.join(scheme_dict[scheme], destination_path)
+            target_path = os.path.join(
+                destination.scheme_dict[scheme], destination_path
+            )
             file_mode = stat.S_IMODE(source._zipfile.getinfo(path).external_attr >> 16)
             if file_mode & 0o111:
                 new_mode = os.stat(target_path).st_mode
@@ -233,7 +339,7 @@ def _install_wheel(
             record_file_path=record_file_path,
             records=written_records,
         )
-        return os.path.join(scheme_dict[root_scheme], source.dist_info_dir)
+        return os.path.join(destination.scheme_dict[root_scheme], source.dist_info_dir)
 
 
 def _get_kind(environment: Environment) -> str:
