@@ -27,6 +27,7 @@ from pdm.utils import (
     expand_env_vars_in_auth,
     get_rev_from_url,
     get_venv_like_prefix,
+    normalize_name,
     path_replace,
     populate_link,
     url_without_fragments,
@@ -355,7 +356,7 @@ class Candidate:
     def as_lockfile_entry(self) -> dict[str, Any]:
         """Build a lockfile entry dictionary for the candidate."""
         result = {
-            "name": self.name,
+            "name": normalize_name(self.name),
             "version": str(self.version),
             "extras": sorted(self.req.extras or ()),
             "requires_python": str(self.requires_python),
