@@ -5,8 +5,10 @@ from typing import TYPE_CHECKING, Dict, List, Optional
 
 from resolvelib import BaseReporter
 
+from pdm import termui
+
 if TYPE_CHECKING:
-    from resolvelib.resolvers import State
+    from resolvelib.resolvers import RequirementInformation, State  # type: ignore
 
     from pdm._vendor import halo
     from pdm.models.candidates import Candidate
@@ -21,7 +23,9 @@ def log_title(title: str) -> None:
 
 
 class SpinnerReporter(BaseReporter):
-    def __init__(self, spinner: halo.Halo, requirements: List[Requirement]) -> None:
+    def __init__(
+        self, spinner: halo.Halo | termui.DummySpinner, requirements: List[Requirement]
+    ) -> None:
         self.spinner = spinner
         self.requirements = requirements
         self._previous: Optional[Dict[str, Candidate]] = None
@@ -51,7 +55,13 @@ class SpinnerReporter(BaseReporter):
         if state.mapping:
             column_width = max(map(len, state.mapping.keys()))
             for k, can in state.mapping.items():
-                logger.info(f"  {k.rjust(column_width)} {can.version}")
+                if not can.req.is_named:
+                    can_info = can.req.url
+                    if can.req.is_vcs:
+                        can_info = f"{can_info}@{can.revision}"
+                else:
+                    can_info = can.version
+                logger.info(f"  {k.rjust(column_width)} {can_info}")
 
     def adding_requirement(self, requirement: Requirement, parent: Candidate) -> None:
         """Called when adding a new requirement into the resolve criteria.
@@ -68,8 +78,15 @@ class SpinnerReporter(BaseReporter):
     def backtracking(self, candidate: Candidate) -> None:
         """Called when rejecting a candidate during backtracking."""
         logger.info(f"Candidate rejected: {candidate.name} {candidate.version}")
-        logger.info("Backtracking...")
 
     def pinning(self, candidate: Candidate) -> None:
         """Called when adding a candidate to the potential solution."""
         self.spinner.text = f"Resolving: new pin {candidate.format()}"
+
+    def resolving_conflicts(self, causes: list[RequirementInformation]) -> None:
+        conflicts = [
+            f"  {req.as_line()} (from {repr(parent) if parent else 'project'})"
+            for req, parent in causes
+        ]
+        logger.info("Conflicts detected: ")
+        logger.info("\n".join(conflicts))
